@@ -23,7 +23,7 @@ extern "C" {
 }
 #endif
 
-const QStringList PackageKitResource::m_objects({QStringLiteral("qrc:/qml/DependenciesButton.qml")});
+const QStringList PackageKitResource::m_objects({QStringLiteral("qrc:/qml/DependenciesButton.qml"), QStringLiteral("qrc:/qml/PackageKitPermissions.qml")});
 
 PackageKitResource::PackageKitResource(QString packageName, QString summary, PackageKitBackend *parent)
     : AbstractResource(parent)
